/*
 * Copyright (C) 2010-2013 jeanfi@gmail.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301 USA
 */

#include <stdio.h>
#include <string.h>

#include <json/json.h>

#include "http.h"
#include "ttrss_ws.h"
#include "url.h"

static struct feed **data;

const char *ttrss_get_headline_content(struct headline *h)
{
	if (!h->content)
		h->content = ws_get_article_content(h->id);

	return h->content;
}

struct feed **ttrss_get_feeds()
{
	struct feed **tmp;

	tmp = ws_update_feeds(data);
	feeds_free(data);
	data = tmp;

	return data;
}

struct headline **ttrss_feed_get_headlines(struct feed *f)
{
	if (!f->headlines)
		ws_update_headlines(f);

	return f->headlines;
}

void ttrss_set_article_unread(int id, int unread)
{
	struct json_object *rp, *rq;

	printf("ttrss_set_article_unread %d %d\n", id, unread);

	rq = ws_request_new("updateArticle");
	json_object_object_add(rq, "article_ids", json_object_new_int(id));
	json_object_object_add(rq, "field", json_object_new_int(2));
	json_object_object_add(rq, "mode", json_object_new_int(unread));

	rp = ws_execute(rq);

	json_object_put(rq);
	json_object_put(rp);
}

void ttrss_set_config(const char *url, const char *user, const char *pwd)
{
	feeds_free(data);
	data = NULL;
	ws_init(url, user, pwd);
}
